var GeoTIFF = require(".");
var fs = require("fs");

// var path = '/Users/fabian/Downloads/LS07_RFUI_ETM_GTC_1P_20010319T081438_20010319T081506_010248_0176_0041_8679/LS07_RFUI_ETM_GTC_1P_20010319T081438_20010319T081506_010248_0176_0041_8679.TIFF/LE71760412001078ESA00_B8.TIF';
var path = 'M3VOLOHD.tif';
// var path = 'x.tif';

fs.readFile(path, function(err, data) {
  if (err) throw err;
  dataArray = data.buffer.slice(data.byteOffset, data.byteOffset + data.byteLength);
  var tiff = GeoTIFF.parse(dataArray);

  console.log(tiff);
  var image = tiff.getImage();
  console.log(image, image.getGeoKeys());
  // ...
});
